summaryrefslogtreecommitdiffstats
path: root/kbabel/filters/xliff/xliffimport.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/filters/xliff/xliffimport.cpp')
-rw-r--r--kbabel/filters/xliff/xliffimport.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kbabel/filters/xliff/xliffimport.cpp b/kbabel/filters/xliff/xliffimport.cpp
index 25f34ec3..9d14c054 100644
--- a/kbabel/filters/xliff/xliffimport.cpp
+++ b/kbabel/filters/xliff/xliffimport.cpp
@@ -1,4 +1,4 @@
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
/* ****************************************************************************
This file is part of KBabel
@@ -26,11 +26,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -47,7 +47,7 @@
optional comments
*/
// Qt include files
#include <tqfile.h>
#include <tqfileinfo.h>
#include <tqobject.h>
@@ -68,12 +68,12 @@ K_EXPORT_COMPONENT_FACTORY( kbabel_xliffimport, KGenericFactory<XLIFFImportPlugi
using namespace KBabel;
-XLIFFImportPlugin::XLIFFImportPlugin( TQObject * parent, const char * name, const TQStringList& )
- : CatalogImportPlugin( parent, name )
+XLIFFImportPlugin::XLIFFImportPlugin( TQObject * tqparent, const char * name, const TQStringList& )
+ : CatalogImportPlugin( tqparent, name )
{
}
-ConversionStatus XLIFFImportPlugin::load( const TQString& filename, const TQString& )
+ConversiontqStatus XLIFFImportPlugin::load( const TQString& filename, const TQString& )
{
if ( filename.isEmpty( ) ) {
kdDebug( KDEBUG_AREA ) << "fatal error: empty filename to open" << endl;
@@ -128,9 +128,9 @@ ConversionStatus XLIFFImportPlugin::load( const TQString& filename, const TQStri
return OK;
}
-void XLIFFImportPlugin::parse( const TQDomElement& parentElement )
+void XLIFFImportPlugin::parse( const TQDomElement& tqparentElement )
{
- TQDomNode node = parentElement.firstChild( );
+ TQDomNode node = tqparentElement.firstChild( );
while ( !node.isNull( ) ) {
if ( node.isElement( ) ) {
@@ -47,7 +47,7 @@
optional comments
*/
-// Qt include files
+// TQt include files
#include <tqfile.h>
#include <tqfileinfo.h>